@@ -6,15 +6,17 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: extern_data.h 2711 2005-01-12 15:03:47Z mosu $
-
    declarations for ComboBox data
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#ifndef __EXTERN_DATA_H
-#define __EXTERN_DATA_H
+#ifndef __MTX_COMMON_EXTERN_DATA_H
+#define __MTX_COMMON_EXTERN_DATA_H
+
+#include "os.h"
+
+#include <string>
 
 typedef struct {
   const char *name, *extensions;
@@ -24,4 +26,7 @@ extern MTX_DLL_API const char *sub_charsets[];
 extern MTX_DLL_API const mime_type_t mime_types[];
 extern MTX_DLL_API const char *cctlds[];
 
-#endif // __EXTERN_DATA_H
+std::string MTX_DLL_API guess_mime_type(std::string ext, bool is_file);
+bool MTX_DLL_API is_valid_cctld(const std::string &s);
+
+#endif // __MTX_COMMON_EXTERN_DATA_H
