@@ -78,8 +78,27 @@ kax_analyzer_c::kax_analyzer_c(mm_file_io_c *file)
 }
 
 kax_analyzer_c::~kax_analyzer_c() {
-  if (m_close_file)
+  close_file();
+}
+
+void
+kax_analyzer_c::close_file() {
+  if (m_close_file) {
     delete m_file;
+    m_file = NULL;
+
+    delete m_stream;
+    m_stream = NULL;
+  }
+}
+
+void
+kax_analyzer_c::reopen_file(const open_mode mode) {
+  if (NULL != m_file)
+    return;
+
+  m_file   = new mm_file_io_c(m_file_name, mode);
+  m_stream = new EbmlStream(*m_file);
 }
 
 void
@@ -94,7 +113,7 @@ kax_analyzer_c::analyzer_debugging_requested(const std::string &section) {
 
 void
 kax_analyzer_c::debug_dump_elements() {
-  int i;
+  size_t i;
   for (i = 0; i < m_data.size(); i++)
     log_debug_message(boost::format("%1%: %2%\n") % i % m_data[i]->to_string());
 }
@@ -111,8 +130,8 @@ kax_analyzer_c::debug_dump_elements_maybe(const std::string &hook_name) {
 void
 kax_analyzer_c::validate_data_structures(const std::string &hook_name) {
   bool gap_debugging = analyzer_debugging_requested("gaps");
-  int i;
-  bool ok = true;
+  bool ok            = true;
+  size_t i;
 
   for (i = 0; m_data.size() -1 > i; i++) {
     if ((m_data[i]->m_pos + m_data[i]->m_size) > m_data[i + 1]->m_pos) {
@@ -135,17 +154,17 @@ kax_analyzer_c::verify_data_structures_against_file(const std::string &hook_name
   kax_analyzer_c actual_content(m_file);
   actual_content.process();
 
-  int num_items    = std::max(m_data.size(), actual_content.m_data.size());
-  bool ok          = m_data.size() == actual_content.m_data.size();
-  int max_info_len = 0;
+  unsigned int num_items = std::max(m_data.size(), actual_content.m_data.size());
+  bool ok                = m_data.size() == actual_content.m_data.size();
+  size_t max_info_len    = 0;
   std::vector<std::string> info_this, info_actual, info_markings;
-  int i;
+  size_t i;
 
   for (i = 0; num_items > i; ++i) {
     info_this.push_back(                 m_data.size() > i ?                m_data[i]->to_string() : empty_string);
     info_actual.push_back(actual_content.m_data.size() > i ? actual_content.m_data[i]->to_string() : empty_string);
 
-    max_info_len           = std::max(max_info_len, static_cast<int>(info_this.back().length()));
+    max_info_len           = std::max(max_info_len, info_this.back().length());
 
     bool row_is_identical  = info_this.back() == info_actual.back();
     ok                    &= row_is_identical;
@@ -185,12 +204,11 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode,
                         const open_mode mode) {
   bool parse_fully = parse_mode_full == parse_mode;
 
-  if (NULL == m_file)
-    try {
-      m_file = new mm_file_io_c(m_file_name, mode);
-    } catch (...) {
-      return false;
-    }
+  try {
+    reopen_file(mode);
+  } catch (...) {
+    return false;
+  }
 
   int64_t file_size = m_file->get_size();
   show_progress_start(file_size);
@@ -272,6 +290,8 @@ kax_analyzer_c::process(kax_analyzer_c::parse_mode_e parse_mode,
 
 EbmlElement *
 kax_analyzer_c::read_element(kax_analyzer_data_c *element_data) {
+  reopen_file();
+
   EbmlStream es(*m_file);
   m_file->setFilePointer(element_data->m_pos);
 
@@ -302,6 +322,8 @@ kax_analyzer_c::read_element(kax_analyzer_data_c *element_data) {
 kax_analyzer_c::update_element_result_e
 kax_analyzer_c::update_element(EbmlElement *e,
                                bool write_defaults) {
+  reopen_file();
+
   fix_mandatory_elements(e);
 
   try {
@@ -324,6 +346,8 @@ kax_analyzer_c::update_element(EbmlElement *e,
 
 kax_analyzer_c::update_element_result_e
 kax_analyzer_c::remove_elements(EbmlId id) {
+  reopen_file();
+
   try {
     call_and_validate({},                          "remove_elements_0");
     call_and_validate(overwrite_all_instances(id), "remove_elements_1");
@@ -398,7 +422,7 @@ kax_analyzer_c::adjust_segment_size() {
       space.
  */
 bool
-kax_analyzer_c::handle_void_elements(int data_idx) {
+kax_analyzer_c::handle_void_elements(size_t data_idx) {
   // Is the element at the end of the file? If so truncate the file
   // and remove the element from the m_data structure if that was
   // requested. Then we're done.
@@ -411,7 +435,7 @@ kax_analyzer_c::handle_void_elements(int data_idx) {
   }
 
   // Are the following elements EbmlVoid elements?
-  int end_idx = data_idx + 1;
+  size_t end_idx = data_idx + 1;
   while ((m_data.size() > end_idx) && (m_data[end_idx]->m_id == EBML_ID(EbmlVoid)))
     ++end_idx;
 
@@ -445,6 +469,51 @@ kax_analyzer_c::handle_void_elements(int data_idx) {
     if (NULL == e)
       return false;
 
+    // However, this might not work if the element's size was already
+    // eight bytes long.
+    if (8 == e->GetSizeLength()) {
+      // In this case try doing the same with the previous
+      // element. The whole element has be moved one byte to the back.
+      delete e;
+
+      e = read_element(m_data[data_idx]);
+      if (NULL == e)
+        return false;
+
+      counted_ptr<EbmlElement> af_e(e);
+
+      // Again the test for maximum size length.
+      if (8 == e->GetSizeLength())
+        return false;
+
+      // Copy the content one byte to the back.
+      unsigned int id_length = EBML_ID_LENGTH(static_cast<const EbmlId &>(*e));
+      uint64_t content_pos   = m_data[data_idx]->m_pos + id_length + e->GetSizeLength();
+      uint64_t content_size  = m_data[data_idx + 1]->m_pos - content_pos - 1;
+      memory_cptr buffer     = memory_c::alloc(content_size);
+
+      m_file->setFilePointer(content_pos);
+      if (m_file->read(buffer, content_size) != content_size)
+        return false;
+
+      m_file->setFilePointer(content_pos + 1);
+      if (m_file->write(buffer) != content_size)
+        return false;
+
+      // Prepare the new codec size and write it.
+      binary head[8];           // Class D + 64 bits coded size
+      int coded_size = CodedSizeLength(content_size, e->GetSizeLength() + 1, true);
+      CodedValueLength(content_size, coded_size, head);
+      m_file->setFilePointer(m_data[data_idx]->m_pos + id_length);
+      if (m_file->write(head, coded_size) != static_cast<unsigned int>(coded_size))
+        return false;
+
+      // Update internal structures.
+      m_data[data_idx]->m_size += 1;
+
+      return true;
+    }
+
     binary head[4 + 8];         // Class D + 64 bits coded size
     unsigned int head_size = EBML_ID_LENGTH(static_cast<const EbmlId &>(*e));
     EbmlId(*e).Fill(head);
@@ -507,7 +576,7 @@ kax_analyzer_c::handle_void_elements(int data_idx) {
  */
 void
 kax_analyzer_c::remove_from_meta_seeks(EbmlId id) {
-  int data_idx;
+  size_t data_idx;
 
   for (data_idx = 0; m_data.size() > data_idx; ++data_idx) {
     // We only have to do work on SeekHead elements. Skip the others.
@@ -525,7 +594,7 @@ kax_analyzer_c::remove_from_meta_seeks(EbmlId id) {
 
     // Iterate over its children and delete the ones we're looking for.
     bool modified = false;
-    int sh_idx    = 0;
+    size_t sh_idx = 0;
     while (seek_head->ListSize() > sh_idx) {
       if (EbmlId(*(*seek_head)[sh_idx]) != EBML_ID(KaxSeek)) {
         ++sh_idx;
@@ -581,7 +650,7 @@ kax_analyzer_c::remove_from_meta_seeks(EbmlId id) {
  */
 void
 kax_analyzer_c::overwrite_all_instances(EbmlId id) {
-  int data_idx;
+  size_t data_idx;
 
   for (data_idx = 0; m_data.size() > data_idx; ++data_idx) {
     // We only have to do work on specific elements. Skip the others.
@@ -604,7 +673,7 @@ kax_analyzer_c::overwrite_all_instances(EbmlId id) {
  */
 void
 kax_analyzer_c::merge_void_elements() {
-  int start_idx = 0;
+  size_t start_idx = 0;
 
   while (m_data.size() > start_idx) {
     // We only have to do work on EbmlVoid elements. Skip the others.
@@ -615,8 +684,8 @@ kax_analyzer_c::merge_void_elements() {
 
     // Found an EbmlVoid element. See how many consecutive EbmlVoid elements
     // there are at this position and calculate the combined size.
-    int end_idx  = start_idx + 1;
-    int new_size = m_data[start_idx]->m_size;
+    size_t end_idx  = start_idx + 1;
+    size_t new_size = m_data[start_idx]->m_size;
     while ((m_data.size() > end_idx) && (m_data[end_idx]->m_id == EBML_ID(EbmlVoid))) {
       new_size += m_data[end_idx]->m_size;
       ++end_idx;
@@ -681,9 +750,9 @@ void
 kax_analyzer_c::write_element(EbmlElement *e,
                               bool write_defaults) {
   e->UpdateSize(write_defaults);
-  int element_size = e->ElementSize(write_defaults);
+  int64_t element_size = e->ElementSize(write_defaults);
 
-  int data_idx;
+  size_t data_idx;
   for (data_idx = 0; m_data.size() > data_idx; ++data_idx) {
     // We're only interested in EbmlVoid elements. Skip the others.
     if (m_data[data_idx]->m_id != EBML_ID(EbmlVoid))
@@ -732,7 +801,8 @@ kax_analyzer_c::write_element(EbmlElement *e,
  */
 void
 kax_analyzer_c::add_to_meta_seek(EbmlElement *e) {
-  int data_idx, first_seek_head_idx = -1;
+  size_t data_idx;
+  int first_seek_head_idx = -1;
 
   for (data_idx = 0; m_data.size() > data_idx; ++data_idx) {
     // We only have to do work on SeekHead elements. Skip the others.
@@ -743,8 +813,8 @@ kax_analyzer_c::add_to_meta_seek(EbmlElement *e) {
     // merge_void_elemens() guarantees that there is no EbmlVoid element
     // at the end of the m_file and that all consecutive EbmlVoid elements
     // have been merged into a single element.
-    int available_space = m_data[data_idx]->m_size;
-    bool void_present   = false;
+    size_t available_space = m_data[data_idx]->m_size;
+    bool void_present      = false;
     if (((data_idx + 1) < m_data.size()) && (m_data[data_idx + 1]->m_id == EBML_ID(EbmlVoid))) {
       available_space += m_data[data_idx + 1]->m_size;
       void_present     = true;
@@ -849,7 +919,7 @@ kax_analyzer_c::add_to_meta_seek(EbmlElement *e) {
       continue;
 
     // Skip the element if it doesn't offer enough space for the seek head.
-    if (m_data[data_idx]->m_size < new_seek_head->ElementSize(true))
+    if (m_data[data_idx]->m_size < static_cast<int64_t>(new_seek_head->ElementSize(true)))
       continue;
 
     // We've found a suitable spot. Write the seek head.
@@ -878,9 +948,11 @@ kax_analyzer_c::add_to_meta_seek(EbmlElement *e) {
 
 EbmlMaster *
 kax_analyzer_c::read_all(const EbmlCallbacks &callbacks) {
+  reopen_file();
+
   EbmlMaster *master = NULL;
   EbmlStream es(*m_file);
-  int i;
+  size_t i;
 
   for (i = 0; m_data.size() > i; ++i) {
     kax_analyzer_data_c &data = *m_data[i].get_object();
@@ -939,7 +1011,7 @@ kax_analyzer_c::read_all_meta_seeks() {
 }
 
 void
-kax_analyzer_c::read_meta_seek(int64_t pos,
+kax_analyzer_c::read_meta_seek(uint64_t pos,
                                std::map<int64_t, bool> &positions_found) {
   if (m_meta_seeks_by_position[pos])
     return;
@@ -990,7 +1062,7 @@ kax_analyzer_c::read_meta_seek(int64_t pos,
 }
 
 void
-kax_analyzer_c::fix_element_sizes(int64_t file_size) {
+kax_analyzer_c::fix_element_sizes(uint64_t file_size) {
   unsigned int i;
   for (i = 0; m_data.size() > i; ++i)
     if (-1 == m_data[i]->m_size)
