@@ -14,9 +14,7 @@
 #ifndef __MTX_COMMON_LOCALE_STRING_H
 #define __MTX_COMMON_LOCALE_STRING_H
 
-#include "common/os.h"
-
-#include <string>
+#include "common/common_pch.h"
 
 #include "common/error.h"
 
