@@ -27,7 +27,7 @@ public:
   virtual void create_file(xtr_base_c *master, KaxTrackEntry &track);
   virtual void handle_frame(memory_cptr &frame, KaxBlockAdditions *additions, int64_t timecode, int64_t duration, int64_t bref, int64_t fref,
                             bool keyframe, bool discardable, bool references_valid);
-  void write_nal(const binary *data, int &pos, int data_size, int nal_size_size);
+  void write_nal(const binary *data, size_t &pos, size_t data_size, size_t nal_size_size);
 
   virtual const char *get_container_name() {
     return "AVC/h.264 elementary stream";
