@@ -73,30 +73,67 @@
 #include "common/endian.h"
 #include "common/matroska.h"
 #include "common/mm_io.h"
+#include "common/stereo_mode.h"
 #include "common/strings/editing.h"
 #include "common/strings/formatting.h"
 #include "common/translation.h"
 #include "common/version.h"
 #include "common/xml/element_mapping.h"
 #include "info/mkvinfo.h"
+#include "info/info_cli_parser.h"
 
 using namespace libmatroska;
 
-typedef struct {
+struct kax_track_t {
   unsigned int tnum, tuid;
   char type;
-  int64_t size;
-} kax_track_t;
+  int64_t default_duration;
 
-std::vector<kax_track_t *> s_tracks;
-std::map<unsigned int, kax_track_t *> s_tracks_by_number, s_tracks_by_uid;
-bool g_use_gui                = false;
-bool g_show_size              = false;
-static bool s_calc_checksums  = false;
-static bool s_show_summary    = false;
-static bool s_show_hexdump    = false;
-static int s_hexdump_max_size = 16;
-static uint64_t s_tc_scale    = TIMECODE_SCALE;
+  kax_track_t();
+};
+
+struct track_info_t {
+  int64_t m_size, m_min_timecode, m_max_timecode, m_blocks, m_blocks_by_ref_num[3], m_add_duration_for_n_packets;
+
+  track_info_t();
+  bool min_timecode_unset();
+  bool max_timecode_unset();
+};
+
+kax_track_t::kax_track_t()
+  : tnum(0)
+  , tuid(0)
+  , type(' ')
+  , default_duration(0)
+{
+}
+typedef counted_ptr<kax_track_t> kax_track_cptr;
+
+track_info_t::track_info_t()
+  : m_size(0)
+  , m_min_timecode(LLONG_MAX)
+  , m_max_timecode(LLONG_MIN)
+  , m_blocks(0)
+  , m_add_duration_for_n_packets(0)
+{
+  memset(m_blocks_by_ref_num, 0, sizeof(int64_t) * 3);
+}
+
+bool
+track_info_t::min_timecode_unset() {
+  return LLONG_MAX == m_min_timecode;
+}
+
+bool
+track_info_t::max_timecode_unset() {
+  return LLONG_MIN == m_max_timecode;
+}
+
+std::vector<kax_track_cptr> s_tracks;
+std::map<unsigned int, kax_track_cptr> s_tracks_by_number, s_tracks_by_uid;
+std::map<unsigned int, track_info_t> s_track_info;
+options_c g_options;
+static uint64_t s_tc_scale = TIMECODE_SCALE;
 std::vector<boost::format> g_common_boost_formats;
 
 #define BF_DO(n)                             g_common_boost_formats[n]
@@ -184,7 +221,7 @@ create_element_text(const std::string &text,
   if ((1 < verbose) && (0 <= position))
     additional_text += (BF_AT % position).str();
 
-  if (g_show_size && (-1 != size)) {
+  if (g_options.m_show_size && (-1 != size)) {
     if (-2 != size)
       additional_text += (BF_SIZE % size).str();
     else
@@ -195,7 +232,7 @@ create_element_text(const std::string &text,
 }
 
 void
-add_track(kax_track_t *t) {
+add_track(kax_track_cptr t) {
   s_tracks.push_back(t);
   s_tracks_by_number[t->tnum] = t;
   s_tracks_by_uid[t->tuid]    = t;
@@ -203,37 +240,12 @@ add_track(kax_track_t *t) {
 
 kax_track_t *
 find_track(int tnum) {
-  return s_tracks_by_number[tnum];
+  return s_tracks_by_number[tnum].get_object();
 }
 
 kax_track_t *
 find_track_by_uid(int tuid) {
-  return s_tracks_by_uid[tuid];
-}
-
-void
-set_usage() {
-  usage_text =
-    Y("Usage: mkvinfo [options] inname\n\n"
-      " options:\n"
-      "  -g, --gui      Start the GUI (and open inname if it was given).\n"
-      "  inname         Use 'inname' as the source.\n"
-      "  -v, --verbose  Increase verbosity. See the man page for a detailed\n"
-      "                 description of what mkvinfo outputs.\n"
-      "  -c, --checksum Calculate and display checksums of frame contents.\n"
-      "  -s, --summary  Only show summaries of the contents, not each element.\n"
-      "  -x, --hexdump  Show the first 16 bytes of each frame as a hex dump.\n"
-      "  -X, --full-hexdump\n"
-      "                 Show all bytes of each frame as a hex dump.\n"
-      "  -z, --size     Show the size of each element including its header.\n"
-      "  --output-charset <charset>\n"
-      "                 Output messages in this charset\n"
-      "  -r, -o, --redirect-output file.ext\n"
-      "                 Redirect all messages to this file.\n"
-      "  -h, --help     Show this help.\n"
-      "  -V, --version  Show version information.\n");
-
-  version_info = get_version_info("mkvinfo", true);
+  return s_tracks_by_uid[tuid].get_object();
 }
 
 #define UTF2STR(s)                 UTFstring_to_cstrutf8(UTFstring(s))
@@ -266,7 +278,7 @@ _show_element(EbmlElement *l,
               bool skip,
               int level,
               const std::string &info) {
-  if (s_show_summary)
+  if (g_options.m_show_summary)
     return;
 
   ui_show_element(level, info,
@@ -305,11 +317,11 @@ create_hexdump(const unsigned char *buf,
   static boost::format s_bf_create_hexdump(" %|1$02x|");
 
   std::string hex(" hexdump");
-  int bmax = std::max(size, s_hexdump_max_size);
+  int bmax = std::min(size, g_options.m_hexdump_max_size);
   int b;
 
   for (b = 0; b < bmax; ++b)
-    hex += (s_bf_create_hexdump % buf[b]).str();
+    hex += (s_bf_create_hexdump % static_cast<int>(buf[b])).str();
 
   return hex;
 }
@@ -367,47 +379,6 @@ create_codec_dependent_private_info(KaxCodecPrivate &c_priv,
   return "";
 }
 
-void
-parse_args(std::vector<std::string> args,
-           std::string &file_name) {
-  size_t i;
-
-  verbose = 0;
-  file_name = "";
-
-  g_use_gui = false;
-
-  set_usage();
-  while (handle_common_cli_args(args, "-o"))
-    set_usage();
-
-  // Now parse the rest of the arguments.
-  for (i = 0; i < args.size(); i++)
-    if ((args[i] == "-g") || (args[i] == "--gui")) {
-      if (!ui_graphical_available())
-        mxerror("mkvinfo was compiled without GUI support.\n");
-      g_use_gui = true;
-    } else if ((args[i] == "-c") || (args[i] == "--checksum"))
-      s_calc_checksums = true;
-    else if ((args[i] == "-C") || (args[i] == "--check-mode")) {
-      s_calc_checksums = true;
-      verbose = 4;
-    } else if ((args[i] == "-s") || (args[i] == "--summary")) {
-      s_calc_checksums = true;
-      s_show_summary = true;
-    } else if ((args[i] == "-x") || (args[i] == "--hexdump"))
-      s_show_hexdump = true;
-    else if ((args[i] == "-X") || (args[i] == "--full-hexdump")) {
-      s_show_hexdump = true;
-      s_hexdump_max_size = INT_MAX;
-    } else if ((args[i] == "-z") || (args[i] == "--size"))
-      g_show_size = true;
-    else if (file_name != "")
-      mxerror(Y("Only one input file is allowed.\n"));
-    else
-      file_name = args[i];
-}
-
 #define in_parent(p) \
   (!p->IsFiniteSize() || \
    (in->getFilePointer() < \
@@ -507,7 +478,7 @@ format_binary(EbmlBinary &bin,
   if (len < bin.GetSize())
     result += "...";
 
-  if (s_calc_checksums)
+  if (g_options.m_calc_checksums)
     result += (BF_FORMAT_BINARY_2 % calc_adler32(bin.GetBuffer(), bin.GetSize())).str();
 
   strip(result);
@@ -779,13 +750,9 @@ def_handle2(video_track,
     } else if (is_id(l4, KaxVideoStereoMode)) {
       KaxVideoStereoMode &stereo = *static_cast<KaxVideoStereoMode *>(l4);
       show_element(l4, 4,
-                   boost::format(Y("Stereo mode: %1%%2%"))
+                   boost::format(Y("Stereo mode: %1% (%2%)"))
                    % uint64(stereo)
-                   % (  uint8(stereo) == 0 ? Y(" (mono)")
-                      : uint8(stereo) == 1 ? Y(" (right eye)")
-                      : uint8(stereo) == 2 ? Y(" (left eye)")
-                      : uint8(stereo) == 3 ? Y(" (both eyes)")
-                      :                      ""));
+                   % stereo_mode_c::translate(static_cast<stereo_mode_c::mode>(uint64(stereo))));
 
     } else if (is_id(l4, KaxVideoAspectRatio)) {
       KaxVideoAspectRatio &ar_type = *static_cast<KaxVideoAspectRatio *>(l4);
@@ -970,13 +937,12 @@ def_handle(tracks) {
       show_element(l2, 2, Y("A track"));
 
       std::vector<std::string> summary;
-      char kax_track_type      = '?';
-      int64_t kax_track_number = -1;
-      bool ms_compat           = false;
-      EbmlMaster *m2           = static_cast<EbmlMaster *>(l2);
+      bool ms_compat = false;
+      EbmlMaster *m2 = static_cast<EbmlMaster *>(l2);
       std::string kax_codec_id;
       std::string fourcc_buffer;
       size_t i2;
+      kax_track_cptr track(new kax_track_t);
 
       for (i2 = 0; i2 < m2->ListSize(); i2++) {
         l3 = (*m2)[i2];
@@ -990,45 +956,48 @@ def_handle(tracks) {
 
         else if (is_id(l3, KaxTrackNumber)) {
           KaxTrackNumber &tnum = *static_cast<KaxTrackNumber *>(l3);
-          kax_track_number     = uint64(tnum);
+          track->tnum          = uint64(tnum);
 
-          show_element(l3, 3, boost::format(Y("Track number: %1%")) % uint64(tnum));
-          if (find_track(uint64(tnum)) != NULL)
-            show_warning(3, boost::format(Y("Warning: There's more than one track with the number %1%.")) % uint64(tnum));
+          show_element(l3, 3, boost::format(Y("Track number: %1%")) % track->tnum);
+          if (find_track(track->tnum) != NULL)
+            show_warning(3, boost::format(Y("Warning: There's more than one track with the number %1%.")) % track->tnum);
+          else
+            add_track(track);
 
         } else if (is_id(l3, KaxTrackUID)) {
           KaxTrackUID &tuid = *static_cast<KaxTrackUID *>(l3);
-          show_element(l3, 3, boost::format(Y("Track UID: %1%")) % uint64(tuid));
-          if (find_track_by_uid(uint64(tuid)) != NULL)
-            show_warning(3, boost::format(Y("Warning: There's more than one track with the UID %1%.")) % uint64(tuid));
+          track->tuid       = uint64(tuid);
+          show_element(l3, 3, boost::format(Y("Track UID: %1%")) % track->tuid);
+          if (find_track_by_uid(track->tuid) != NULL)
+            show_warning(3, boost::format(Y("Warning: There's more than one track with the UID %1%.")) % track->tuid);
 
         } else if (is_id(l3, KaxTrackType)) {
           KaxTrackType &ttype = *static_cast<KaxTrackType *>(l3);
 
           switch (uint8(ttype)) {
             case track_audio:
-              kax_track_type = 'a';
+              track->type = 'a';
               break;
             case track_video:
-              kax_track_type = 'v';
+              track->type = 'v';
               break;
             case track_subtitle:
-              kax_track_type = 's';
+              track->type = 's';
               break;
             case track_buttons:
-              kax_track_type = 'b';
+              track->type = 'b';
               break;
             default:
-              kax_track_type = '?';
+              track->type = '?';
               break;
           }
           show_element(l3, 3,
                        boost::format(Y("Track type: %1%"))
-                       % (  'a' == kax_track_type ? "audio"
-                          : 'v' == kax_track_type ? "video"
-                          : 's' == kax_track_type ? "subtitles"
-                          : 'b' == kax_track_type ? "buttons"
-                          :                         "unknown"));
+                       % (  'a' == track->type ? "audio"
+                          : 'v' == track->type ? "video"
+                          : 's' == track->type ? "subtitles"
+                          : 'b' == track->type ? "buttons"
+                          :                      "unknown"));
 
 #if MATROSKA_VERSION >= 2
         } else if (is_id(l3, KaxTrackFlagEnabled)) {
@@ -1045,18 +1014,18 @@ def_handle(tracks) {
           kax_codec_id         = std::string(codec_id);
 
           show_element(l3, 3, boost::format(Y("Codec ID: %1%")) % kax_codec_id);
-          if (   ((kax_codec_id == MKV_V_MSCOMP) && ('v' == kax_track_type))
-              || ((kax_codec_id == MKV_A_ACM)    && ('a' == kax_track_type)))
+          if (   ((kax_codec_id == MKV_V_MSCOMP) && ('v' == track->type))
+              || ((kax_codec_id == MKV_A_ACM)    && ('a' == track->type)))
             ms_compat = true;
 
         } else if (is_id(l3, KaxCodecPrivate)) {
           KaxCodecPrivate &c_priv = *static_cast<KaxCodecPrivate *>(l3);
-          fourcc_buffer = create_codec_dependent_private_info(c_priv, kax_track_type, kax_codec_id);
+          fourcc_buffer = create_codec_dependent_private_info(c_priv, track->type, kax_codec_id);
 
-          if (s_calc_checksums && !s_show_summary)
+          if (g_options.m_calc_checksums && !g_options.m_show_summary)
             fourcc_buffer += (boost::format(Y(" (adler: 0x%|1$08x|)")) % calc_adler32(c_priv.GetBuffer(), c_priv.GetSize())).str();
 
-          if (s_show_hexdump)
+          if (g_options.m_show_hexdump)
             fourcc_buffer += create_hexdump(c_priv.GetBuffer(), c_priv.GetSize());
 
           show_element(l3, 3, boost::format(Y("CodecPrivate, length %1%%2%")) % c_priv.GetSize() % fourcc_buffer);
@@ -1106,6 +1075,7 @@ def_handle(tracks) {
                              % ((float)uint64(def_duration) / 1000000.0)
                              % (1000000000.0 / (float)uint64(def_duration))
                              ).str());
+          track->default_duration = uint64(def_duration);
 
         } else if (is_id(l3, KaxTrackFlagLacing)) {
           KaxTrackFlagLacing &f_lacing = *static_cast<KaxTrackFlagLacing *>(l3);
@@ -1140,14 +1110,14 @@ def_handle(tracks) {
 
       }
 
-      if (s_show_summary)
+      if (g_options.m_show_summary)
         mxinfo(boost::format(Y("Track %1%: %2%, codec ID: %3%%4%%5%%6%\n"))
-               % kax_track_number
-               % (  'a' == kax_track_type ? Y("audio")
-                  : 'v' == kax_track_type ? Y("video")
-                  : 's' == kax_track_type ? Y("subtitles")
-                  : 'b' == kax_track_type ? Y("buttons")
-                  :                         Y("unknown"))
+               % track->tnum
+               % (  'a' == track->type ? Y("audio")
+                  : 'v' == track->type ? Y("video")
+                  : 's' == track->type ? Y("subtitles")
+                  : 'b' == track->type ? Y("buttons")
+                  :                      Y("unknown"))
                % kax_codec_id
                % fourcc_buffer
                % (summary.empty() ? "" : ", ")
@@ -1162,7 +1132,7 @@ def_handle(tracks) {
 
 void
 def_handle(seek_head) {
-  if ((verbose < 2) && !g_use_gui) {
+  if ((verbose < 2) && !g_options.m_use_gui) {
     show_element(l1, 1, Y("Seek head (subentries will be skipped)"));
     return;
   }
@@ -1430,7 +1400,7 @@ def_handle2(block_group,
                    % ((float)block.GlobalTimecode() / 1000000000.0)
                    % format_timecode(block.GlobalTimecode(), 3));
 
-      lf_timecode = block.GlobalTimecode() / 1000000;
+      lf_timecode = block.GlobalTimecode();
       lf_tnum     = block.TrackNum();
       bduration   = -1.0;
       frame_pos   = block.GetElementPosition() + block.ElementSize();
@@ -1441,11 +1411,11 @@ def_handle2(block_group,
         uint32_t adler   = calc_adler32(data.Buffer(), data.Size());
 
         std::string adler_str;
-        if (s_calc_checksums)
+        if (g_options.m_calc_checksums)
           adler_str = (BF_BLOCK_GROUP_BLOCK_ADLER % adler).str();
 
         std::string hex;
-        if (s_show_hexdump)
+        if (g_options.m_show_hexdump)
           hex = create_hexdump(data.Buffer(), data.Size());
 
         show_element(NULL, 4, BF_BLOCK_GROUP_BLOCK_FRAME % data.Size() % adler_str % hex);
@@ -1577,7 +1547,7 @@ def_handle2(block_group,
 
   } // while (l3 != NULL)
 
-  if (s_show_summary) {
+  if (g_options.m_show_summary) {
     std::string position;
     size_t fidx;
 
@@ -1591,8 +1561,8 @@ def_handle2(block_group,
         mxinfo(BF_BLOCK_GROUP_SUMMARY_WITH_DURATION
                % (bref_found && fref_found ? 'B' : bref_found ? 'P' : !fref_found ? 'I' : 'P')
                % lf_tnum
-               % lf_timecode
-               % format_timecode(lf_timecode * 1000000, 3)
+               % (lf_timecode / 1000000)
+               % format_timecode(lf_timecode, 3)
                % bduration
                % frame_sizes[fidx]
                % frame_adlers[fidx]
@@ -1602,8 +1572,8 @@ def_handle2(block_group,
         mxinfo(BF_BLOCK_GROUP_SUMMARY_NO_DURATION
                % (bref_found && fref_found ? 'B' : bref_found ? 'P' : !fref_found ? 'I' : 'P')
                % lf_tnum
-               % lf_timecode
-               % format_timecode(lf_timecode * 1000000, 3)
+               % (lf_timecode / 1000000)
+               % format_timecode(lf_timecode, 3)
                % frame_sizes[fidx]
                % frame_adlers[fidx]
                % frame_hexdumps[fidx]
@@ -1615,7 +1585,28 @@ def_handle2(block_group,
                  BF_BLOCK_GROUP_SUMMARY_V2
                  % (bref_found && fref_found ? 'B' : bref_found ? 'P' : !fref_found ? 'I' : 'P')
                  % lf_tnum
-                 % lf_timecode);
+                 % (lf_timecode / 1000000));
+
+  track_info_t &tinfo = s_track_info[lf_tnum];
+
+  tinfo.m_blocks                                                                                 += frame_sizes.size();
+  tinfo.m_blocks_by_ref_num[bref_found && fref_found ? 2 : bref_found ? 1 : !fref_found ? 0 : 1] += frame_sizes.size();
+  tinfo.m_min_timecode                                                                             = std::min(tinfo.m_min_timecode, lf_timecode);
+
+  if (tinfo.max_timecode_unset() || (tinfo.m_max_timecode < lf_timecode)) {
+    tinfo.m_max_timecode = lf_timecode;
+
+    if (-1 == bduration)
+      tinfo.m_add_duration_for_n_packets  = frame_sizes.size();
+    else {
+      tinfo.m_max_timecode               += bduration * 1000000.0;
+      tinfo.m_add_duration_for_n_packets  = 0;
+    }
+  }
+
+  size_t fidx;
+  for (fidx = 0; fidx < frame_sizes.size(); fidx++)
+    tinfo.m_size += frame_sizes[fidx];
 }
 
 void
@@ -1627,9 +1618,9 @@ def_handle2(simple_block,
   KaxSimpleBlock &block = *static_cast<KaxSimpleBlock *>(l2);
   block.SetParent(*cluster);
 
-  int64_t frame_pos = block.GetElementPosition() + block.ElementSize();
-
-  uint64_t timecode = block.GlobalTimecode() / 1000000;
+  int64_t frame_pos   = block.GetElementPosition() + block.ElementSize();
+  uint64_t timecode   = block.GlobalTimecode() / 1000000;
+  track_info_t &tinfo = s_track_info[block.TrackNum()];
 
   std::string info;
   if (block.IsKeyframe())
@@ -1650,12 +1641,14 @@ def_handle2(simple_block,
     DataBuffer &data = block.GetBuffer(i);
     uint32_t adler   = calc_adler32(data.Buffer(), data.Size());
 
+    tinfo.m_size += data.Size();
+
     std::string adler_str;
-    if (s_calc_checksums)
+    if (g_options.m_calc_checksums)
       adler_str = (BF_SIMPLE_BLOCK_ADLER % adler).str();
 
     std::string hex;
-    if (s_show_hexdump)
+    if (g_options.m_show_hexdump)
       hex = create_hexdump(data.Buffer(), data.Size());
 
     show_element(NULL, 3, BF_SIMPLE_BLOCK_FRAME % data.Size() % adler_str % hex);
@@ -1665,7 +1658,7 @@ def_handle2(simple_block,
     frame_pos -= data.Size();
   }
 
-  if (s_show_summary) {
+  if (g_options.m_show_summary) {
     std::string position;
     size_t fidx;
 
@@ -1691,6 +1684,16 @@ def_handle2(simple_block,
                  % (block.IsKeyframe() ? 'I' : block.IsDiscardable() ? 'B' : 'P')
                  % block.TrackNum()
                  % timecode);
+
+  tinfo.m_blocks                                                                    += block.NumberFrames();
+  tinfo.m_blocks_by_ref_num[block.IsKeyframe() ? 0 : block.IsDiscardable() ? 2 : 1] += block.NumberFrames();
+  tinfo.m_min_timecode                                                                = std::min(tinfo.m_min_timecode, static_cast<int64_t>(block.GlobalTimecode()));
+  tinfo.m_max_timecode                                                                = std::max(tinfo.m_min_timecode, static_cast<int64_t>(block.GlobalTimecode()));
+  tinfo.m_add_duration_for_n_packets                                                  = block.NumberFrames();
+
+  size_t fidx;
+  for (fidx = 0; fidx < frame_sizes.size(); fidx++)
+    tinfo.m_size += frame_sizes[fidx];
 }
 
 void
@@ -1699,7 +1702,7 @@ def_handle3(cluster,
             int64_t file_size) {
   cluster = (KaxCluster *)l1;
 
-  if (g_use_gui)
+  if (g_options.m_use_gui)
     ui_show_progress(100 * cluster->GetElementPosition() / file_size, Y("Parsing file"));
 
   upper_lvl_el               = 0;
@@ -1880,6 +1883,33 @@ handle_ebml_head(EbmlElement *l0,
   }
 }
 
+void
+display_track_info() {
+  if (!g_options.m_show_track_info)
+    return;
+
+  size_t idx;
+  for (idx = 0; s_tracks.size() > idx; ++idx) {
+    kax_track_cptr track = s_tracks[idx];
+    track_info_t &tinfo  = s_track_info[track->tnum];
+
+    if (tinfo.min_timecode_unset())
+      tinfo.m_min_timecode = 0;
+    if (tinfo.max_timecode_unset())
+      tinfo.m_max_timecode = tinfo.m_min_timecode;
+
+    int64_t duration  = tinfo.m_max_timecode - tinfo.m_min_timecode;
+    duration         += tinfo.m_add_duration_for_n_packets * track->default_duration;
+
+    mxinfo(boost::format(Y("Statistics for track number %1%: number of blocks: %2%; size in bytes: %3%; duration in seconds: %4%; approximate bitrate in bits/second: %5%\n"))
+           % track->tnum
+           % tinfo.m_blocks
+           % tinfo.m_size
+           % (duration / 1000000000.0)
+           % static_cast<uint64_t>(duration == 0 ? 0 : tinfo.m_size * 8000000000.0 / duration));
+  }
+}
+
 bool
 process_file(const std::string &file_name) {
   int upper_lvl_el;
@@ -1957,7 +1987,7 @@ process_file(const std::string &file_name) {
 
       else if (is_id(l1, KaxCluster)) {
         show_element(l1, 1, Y("Cluster"));
-        if ((verbose == 0) && !s_show_summary) {
+        if ((verbose == 0) && !g_options.m_show_summary) {
           delete l1;
           delete l0;
           delete es;
@@ -2014,6 +2044,9 @@ process_file(const std::string &file_name) {
     delete es;
     delete in;
 
+    if (!g_options.m_use_gui && g_options.m_show_track_info)
+      display_track_info();
+
     return true;
   } catch (...) {
     show_error(Y("Caught exception"));
@@ -2030,41 +2063,29 @@ setup(const std::string &locale) {
   init_locales(locale);
 
   init_common_boost_formats();
+
+  version_info = get_version_info("mkvinfo", true);
 }
 
 int
-console_main(std::vector<std::string> args) {
-  std::string file_name;
-  bool ok;
-
+console_main() {
   set_process_priority(-1);
 
-  parse_args(args, file_name);
-  if (file_name == "") {
-    usage();
-    mxexit(0);
-  }
-  ok = process_file(file_name.c_str());
+  if (g_options.m_file_name.empty())
+    mxerror(Y("No file name given.\n"));
 
-  if (ok)
-    return 0;
-  else
-    return 1;
+  return process_file(g_options.m_file_name.c_str()) ? 0 : 1;
 }
 
 int
 main(int argc,
      char **argv) {
-  std::vector<std::string> args;
-  std::string initial_file;
-
   setup();
 
-  args = command_line_utf8(argc, argv);
-  parse_args(args, initial_file);
+  g_options = info_cli_parser_c(command_line_utf8(argc, argv)).run();
 
-  if (g_use_gui)
+  if (g_options.m_use_gui)
     return ui_run(argc, argv);
   else
-    return console_main(args);
+    return console_main();
 }
