@@ -72,12 +72,13 @@ private:
   std::vector<avi_demuxer_t> m_audio_demuxers;
   std::vector<avi_subs_demuxer_t> m_subtitle_demuxers;
   double m_fps;
-  int m_video_frames_read, m_max_video_frames, m_dropped_video_frames, m_act_wchar;
+  unsigned int m_video_frames_read, m_max_video_frames, m_dropped_video_frames, m_act_wchar;
   bool m_is_divx;
   memory_cptr m_avc_extra_nalus;
   int m_avc_nal_size_size;
 
   int64_t m_bytes_to_process, m_bytes_processed;
+  bool m_video_track_ok;
 
 public:
   avi_reader_c(track_info_c &_ti) throw (error_c);
@@ -90,7 +91,7 @@ public:
   virtual void create_packetizer(int64_t tid);
   virtual void add_available_track_ids();
 
-  static int probe_file(mm_io_c *io, int64_t size);
+  static int probe_file(mm_io_c *io, uint64_t size);
 
 protected:
   virtual void add_audio_demuxer(int aid);
@@ -100,6 +101,7 @@ protected:
   virtual memory_cptr extract_avcc();
 
   virtual generic_packetizer_c *create_aac_packetizer(int aid, avi_demuxer_t &demuxer);
+  virtual generic_packetizer_c *create_dts_packetizer(int aid);
   virtual generic_packetizer_c *create_vorbis_packetizer(int aid);
   virtual void create_subs_packetizer(int idx);
   virtual void create_srt_packetizer(int idx);
@@ -108,10 +110,12 @@ protected:
   virtual void create_mpeg1_2_packetizer();
   virtual void create_mpeg4_p2_packetizer();
   virtual void create_mpeg4_p10_packetizer();
+  virtual void create_video_packetizer();
 
   void extended_identify_mpeg4_l2(std::vector<std::string> &extended_info);
 
   void parse_subtitle_chunks();
+  void verify_video_track();
 
   virtual void identify_video();
   virtual void identify_audio();
