@@ -20,7 +20,7 @@
 
 int
 mp3_reader_c::probe_file(mm_io_c *io,
-                         int64_t,
+                         uint64_t,
                          int64_t probe_range,
                          int num_headers) {
   return (find_valid_headers(io, probe_range, num_headers) != -1) ? 1 : 0;
@@ -65,7 +65,7 @@ mp3_reader_c::~mp3_reader_c() {
 
 void
 mp3_reader_c::create_packetizer(int64_t) {
-  if (NPTZR() != 0)
+  if (!demuxing_requested('a', 0) || (NPTZR() != 0))
     return;
 
   mxinfo_tid(m_ti.m_fname, 0, Y("Using the MPEG audio output module.\n"));
@@ -76,10 +76,8 @@ file_status_e
 mp3_reader_c::read(generic_packetizer_c *,
                    bool) {
   int nread = io->read(chunk, 16384);
-  if (0 >= nread) {
-    PTZR0->flush();
-    return FILE_STATUS_DONE;
-  }
+  if (0 >= nread)
+    return flush_packetizers();
 
   PTZR0->process(new packet_t(new memory_c(chunk, nread, false)));
   bytes_processed += nread;
