@@ -29,7 +29,7 @@ private:
   mm_io_c *io;
   int64_t bytes_processed, size;
   std::vector<uint32_t> seek_points;
-  int pos;
+  unsigned int pos;
   tta_file_header_t header;
 
 public:
@@ -41,7 +41,7 @@ public:
   virtual void identify();
   virtual void create_packetizer(int64_t id);
 
-  static int probe_file(mm_io_c *io, int64_t size);
+  static int probe_file(mm_io_c *io, uint64_t size);
 };
 
 #endif // __R_TTA_H
