@@ -46,6 +46,7 @@ cluster_helper_c::cluster_helper_c()
   , m_first_timecode_in_file(-1)
   , m_min_timecode_in_cluster(-1)
   , m_max_timecode_in_cluster(-1)
+  , m_attachments_size(0)
   , m_out(NULL)
   , m_current_split_point(m_split_points.begin())
 {
@@ -65,11 +66,11 @@ cluster_helper_c::add_packet(packet_cptr packet) {
   packet->unmodified_duration          = packet->duration;
   packet->timecode                     = RND_TIMECODE_SCALE(packet->timecode);
   packet->assigned_timecode            = RND_TIMECODE_SCALE(packet->assigned_timecode);
-  if (0 < packet->duration)
+  if (packet->has_duration())
     packet->duration                   = RND_TIMECODE_SCALE(packet->duration);
-  if (0 < packet->bref)
+  if (packet->has_bref())
     packet->bref                       = RND_TIMECODE_SCALE(packet->bref);
-  if (0 < packet->fref)
+  if (packet->has_fref())
     packet->fref                       = RND_TIMECODE_SCALE(packet->fref);
 
   int64_t timecode        = get_timecode();
@@ -88,7 +89,8 @@ cluster_helper_c::add_packet(packet_cptr packet) {
   if (   (SHRT_MAX < timecode_delay)
       || (SHRT_MIN > timecode_delay)
       || (packet->gap_following && !m_packets.empty())
-      || ((packet->assigned_timecode - timecode) > g_max_ns_per_cluster)) {
+      || ((packet->assigned_timecode - timecode) > g_max_ns_per_cluster)
+      || ((packet->source == g_video_packetizer) && packet->is_key_frame())) {
     render();
     prepare_new_cluster();
   }
@@ -96,7 +98,7 @@ cluster_helper_c::add_packet(packet_cptr packet) {
   if (   splitting()
       && (m_split_points.end() != m_current_split_point)
       && (g_file_num <= g_split_max_num_files)
-      && (packet->bref == -1)
+      && packet->is_key_frame()
       && (   (packet->source->get_track_type() == track_video)
           || (NULL == g_video_packetizer))) {
     bool split_now = false;
@@ -113,7 +115,7 @@ cluster_helper_c::add_packet(packet_cptr packet) {
         std::vector<packet_cptr>::iterator p_it;
         mxforeach(p_it, m_packets) {
           packet_cptr &p   = *p_it;
-          additional_size += p->data->get_size() + ((-1 == p->bref) ? 10 : (-1 == p->fref) ? 13 : 16);
+          additional_size += p->data->get_size() + (p->is_key_frame() ? 10 : p->is_p_frame() ? 13 : 16);
         }
 
       } else
@@ -179,7 +181,7 @@ cluster_helper_c::add_packet(packet_cptr packet) {
 
   // Render the cluster if it is full (according to my many criteria).
   timecode = get_timecode();
-  if (((packet->assigned_timecode - timecode) > g_max_ns_per_cluster) || (m_packets.size() > g_max_blocks_per_cluster) || (get_cluster_content_size() > 1500000)) {
+  if (((packet->assigned_timecode - timecode) > g_max_ns_per_cluster) || (m_packets.size() > static_cast<size_t>(g_max_blocks_per_cluster)) || (get_cluster_content_size() > 1500000)) {
     render();
     prepare_new_cluster();
   }
@@ -221,7 +223,7 @@ cluster_helper_c::set_duration(render_groups_c *rg) {
   int64_t def_duration    = rg->m_source->get_track_default_duration();
   int64_t block_duration  = 0;
 
-  int i;
+  size_t i;
   for (i = 0; rg->m_durations.size() > i; ++i)
     block_duration += rg->m_durations[i];
   mxverb(3,
@@ -231,7 +233,7 @@ cluster_helper_c::set_duration(render_groups_c *rg) {
   if (rg->m_duration_mandatory) {
     if (   (0 == block_duration)
         || (   (0 < block_duration)
-            && (block_duration != (rg->m_durations.size() * def_duration))))
+            && (block_duration != (static_cast<int64_t>(rg->m_durations.size()) * def_duration))))
       group->set_block_duration(RND_TIMECODE_SCALE(block_duration));
 
   } else if (   (   g_use_durations
@@ -244,7 +246,7 @@ cluster_helper_c::set_duration(render_groups_c *rg) {
 bool
 cluster_helper_c::must_duration_be_set(render_groups_c *rg,
                                        packet_cptr &new_packet) {
-  int i;
+  size_t i;
   int64_t block_duration = 0;
   int64_t def_duration   = rg->m_source->get_track_default_duration();
 
@@ -255,7 +257,7 @@ cluster_helper_c::must_duration_be_set(render_groups_c *rg,
   if (rg->m_duration_mandatory || new_packet->duration_mandatory) {
     if (   (0 == block_duration)
         || (   (0 < block_duration)
-            && (block_duration != ((rg->m_durations.size() + 1) * def_duration))))
+            && (block_duration != ((static_cast<int64_t>(rg->m_durations.size()) + 1) * def_duration))))
       return true;
 
   } else if (   (   g_use_durations
@@ -330,7 +332,7 @@ cluster_helper_c::render() {
     kax_block_blob_c *previous_block_group = !render_group->m_groups.empty() ? render_group->m_groups.back().get_object() : NULL;
     kax_block_blob_c *new_block_group      = previous_block_group;
 
-    if ((-1 != pack->bref) || has_codec_state)
+    if (!pack->is_key_frame() || has_codec_state)
       render_group->m_more_data = false;
 
     if (!render_group->m_more_data) {
@@ -356,8 +358,8 @@ cluster_helper_c::render() {
 
     // Now put the packet into the cluster.
     render_group->m_more_data = new_block_group->add_frame_auto(track_entry, pack->assigned_timecode - m_timecode_offset, *data_buffer, lacing_type,
-                                                                (-1 == pack->bref) ? -1 : pack->bref - m_timecode_offset,
-                                                                (-1 == pack->fref) ? -1 : pack->fref - m_timecode_offset);
+                                                                pack->has_bref() ? pack->bref - m_timecode_offset : -1,
+                                                                pack->has_fref() ? pack->fref - m_timecode_offset : -1);
 
     if (has_codec_state) {
       KaxBlockGroup &bgroup = (KaxBlockGroup &)*new_block_group;
@@ -372,7 +374,7 @@ cluster_helper_c::render() {
     if ((pack->assigned_timecode + pack->duration) > m_max_timecode_and_duration)
       m_max_timecode_and_duration = pack->assigned_timecode + pack->duration;
 
-    if ((-1 != pack->bref) || (-1 != pack->fref) || !track_entry.LacingEnabled())
+    if (!pack->is_key_frame() || !track_entry.LacingEnabled())
       render_group->m_more_data = false;
 
     render_group->m_durations.push_back(pack->unmodified_duration);
@@ -387,7 +389,7 @@ cluster_helper_c::render() {
       if (!pack->data_adds.empty() && new_block_group->ReplaceSimpleByGroup()) {
         KaxBlockAdditions &additions = AddEmptyChild<KaxBlockAdditions>(*new_block_group);
 
-        int data_add_idx;
+        size_t data_add_idx;
         for (data_add_idx = 0; pack->data_adds.size() > data_add_idx; ++data_add_idx) {
           KaxBlockMore &block_more                                           = AddEmptyChild<KaxBlockMore>(additions);
           GetChildAs<KaxBlockAddID, EbmlUInteger>(block_more) = data_add_idx + 1;
@@ -406,7 +408,7 @@ cluster_helper_c::render() {
       // Update the cues (index table) either if cue entries for
       // I frames were requested and this is an I frame...
       if ((   (CUE_STRATEGY_IFRAMES == source->get_cue_creation())
-           && (-1 == pack->bref))
+           && pack->is_key_frame())
           // ... or if a codec state change is present ...
           || has_codec_state
           // ... or if the user requested entries for all frames ...
