@@ -66,6 +66,7 @@
 #include "common/hacks.h"
 #include "common/math.h"
 #include "common/mm_io.h"
+#include "common/mm_write_cache_io.h"
 #include "common/strings/formatting.h"
 #include "common/tags/tags.h"
 #include "common/translation.h"
@@ -90,6 +91,7 @@
 #include "input/r_mpeg_ps.h"
 #include "input/r_mpeg_ts.h"
 #include "input/r_ogm.h"
+#include "input/r_pgssup.h"
 #include "input/r_qtmp4.h"
 #include "input/r_real.h"
 #include "input/r_srt.h"
@@ -136,7 +138,7 @@ KaxInfo *g_kax_info_chap                    = NULL;
 std::string g_outfile;
 int64_t g_file_sizes                        = 0;
 int g_max_blocks_per_cluster                = 65535;
-int64_t g_max_ns_per_cluster                = 2000000000;
+int64_t g_max_ns_per_cluster                = 5000000000ll;
 bool g_write_cues                           = true;
 bool g_cue_writing_requested                = false;
 generic_packetizer_c *g_video_packetizer    = NULL;
@@ -324,6 +326,8 @@ get_file_type(filelist_t &file) {
     type = FILE_TYPE_OGM;
   else if (flac_reader_c::probe_file(io, size))
     type = FILE_TYPE_FLAC;
+  else if (pgssup_reader_c::probe_file(io, size))
+    type = FILE_TYPE_PGSSUP;
   else if (real_reader_c::probe_file(io, size))
     type = FILE_TYPE_REAL;
   else if (qtmp4_reader_c::probe_file(io, size))
@@ -348,8 +352,8 @@ get_file_type(filelist_t &file) {
   else {
     // File types which are the same in raw format and in other container formats.
     // Detection requires 20 or more consecutive packets.
-    static const int s_probe_sizes[]                          = { 32 * 1024, 64 * 1024, 128 * 1024, 256 * 1024, 512 * 1024, 1024 * 1024, 0 };
-    static const int s_probe_num_required_consecutive_packets = 20;
+    static const int s_probe_sizes[]                          = { 128 * 1024, 256 * 1024, 512 * 1024, 1024 * 1024, 0 };
+    static const int s_probe_num_required_consecutive_packets = 64;
 
     int i;
     for (i = 0; (0 != s_probe_sizes[i]) && (FILE_TYPE_IS_UNKNOWN == type); ++i)
@@ -372,6 +376,21 @@ get_file_type(filelist_t &file) {
   else if (avc_es_reader_c::probe_file(io, size))
     type = FILE_TYPE_AVC_ES;
   else {
+    // File types which are the same in raw format and in other container formats.
+    // Detection requires 20 or more consecutive packets.
+    static const int s_probe_sizes[]                          = { 32 * 1024, 64 * 1024, 128 * 1024, 256 * 1024, 512 * 1024, 1024 * 1024, 0 };
+    static const int s_probe_num_required_consecutive_packets = 20;
+
+    int i;
+    for (i = 0; (0 != s_probe_sizes[i]) && (FILE_TYPE_IS_UNKNOWN == type); ++i)
+      if (mp3_reader_c::probe_file(io, size, s_probe_sizes[i], s_probe_num_required_consecutive_packets))
+        type = FILE_TYPE_MP3;
+      else if (ac3_reader_c::probe_file(io, size, s_probe_sizes[i], s_probe_num_required_consecutive_packets))
+        type = FILE_TYPE_AC3;
+      else if (aac_reader_c::probe_file(io, size, s_probe_sizes[i], s_probe_num_required_consecutive_packets))
+        type = FILE_TYPE_AAC;
+  }
+  if (FILE_TYPE_IS_UNKNOWN == type) {
     // All text file types (subtitles).
     mm_text_io_c *text_io = NULL;
     try {
@@ -415,10 +434,16 @@ display_progress() {
   if (NULL == s_display_reader) {
     std::vector<filelist_t>::const_iterator i;
 
-    const filelist_t *winner = &g_files[0];
-    for (i = g_files.begin() + 1; i != g_files.end(); ++i)
-      if (!i->appending && (i->size > winner->size))
-        winner = &(*i);
+    const filelist_t *winner = NULL;
+    foreach(const filelist_t &current, g_files)
+      if (!current.appending && (0 != current.reader->get_num_packetizers()) && ((NULL == winner) || (current.size > winner->size)))
+        winner = &current;
+
+    if (NULL == winner) {
+      foreach(const filelist_t &current, g_files)
+        if (!current.appending && ((NULL == winner) || (current.size > winner->size)))
+          winner = &current;
+    }
 
     s_display_reader = winner->reader;
   }
@@ -622,7 +647,7 @@ render_headers(mm_io_c *out) {
 
     // Set the segment family
     if (!g_segfamily_uids.empty()) {
-      int i;
+      size_t i;
       for (i = 0; i < g_segfamily_uids.size(); i++)
         AddNewChild<KaxSegmentFamily>(*s_kax_infos).CopyBuffer(g_segfamily_uids[i].data(), 128 / 8);
     }
@@ -668,9 +693,9 @@ render_headers(mm_io_c *out) {
     if (first_file) {
       g_kax_last_entry = NULL;
 
-      int i;
+      size_t i;
       for (i = 0; i < g_track_order.size(); i++)
-        if ((g_track_order[i].file_id >= 0) && (g_track_order[i].file_id < g_files.size()) && !g_files[g_track_order[i].file_id].appending)
+        if ((g_track_order[i].file_id >= 0) && (g_track_order[i].file_id < static_cast<int>(g_files.size())) && !g_files[g_track_order[i].file_id].appending)
           g_files[g_track_order[i].file_id].reader->set_headers_for_track(g_track_order[i].track_id);
 
       for (i = 0; i < g_files.size(); i++)
@@ -736,7 +761,7 @@ rerender_track_headers() {
 /** \brief Render all attachments into the output file at the current position
 
    This function also makes sure that no duplicates are output. This might
-   happen when appending g_files.
+   happen when appending files.
 */
 static void
 render_attachments(IOCallback *out) {
@@ -786,7 +811,7 @@ render_attachments(IOCallback *out) {
 /** \brief Check the complete append mapping mechanism
 
    Each entry given with '--append-to' has to be checked for validity.
-   For g_files that aren't managed with '--append-to' default entries have
+   For files that aren't managed with '--append-to' default entries have
    to be created.
 */
 static void
@@ -794,13 +819,13 @@ check_append_mapping() {
   std::vector<append_spec_t>::iterator amap, cmp_amap, trav_amap;
   std::vector<int64_t>::iterator id;
   std::vector<filelist_t>::iterator src_file, dst_file;
-  int count, file_id;
+  int file_id;
 
   mxforeach(amap, g_append_mapping) {
     // Check each mapping entry for validity.
 
     // 1. Is there a file with the src_file_id?
-    if ((0 > amap->src_file_id) || (g_files.size() <= amap->src_file_id))
+    if ((0 > amap->src_file_id) || (g_files.size() <= static_cast<size_t>(amap->src_file_id)))
       mxerror(boost::format(Y("There is no file with the ID '%1%'. The argument for '--append-to' was invalid.\n")) % amap->src_file_id);
 
     // 2. Is the "source" file in "append mode", meaning does its file name
@@ -810,7 +835,7 @@ check_append_mapping() {
       mxerror(boost::format(Y("The file no. %1% ('%2%') is not being appended. The argument for '--append-to' was invalid.\n")) % amap->src_file_id % src_file->name);
 
     // 3. Is there a file with the dst_file_id?
-    if ((0 > amap->dst_file_id) || (g_files.size() <= amap->dst_file_id))
+    if ((0 > amap->dst_file_id) || (g_files.size() <= static_cast<size_t>(amap->dst_file_id)))
       mxerror(boost::format(Y("There is no file with the ID '%1%'. The argument for '--append-to' was invalid.\n")) % amap->dst_file_id);
 
     // 4. G_Files cannot be appended to itself.
@@ -826,7 +851,7 @@ check_append_mapping() {
     if (!src_file->appending)
       continue;
 
-    count = 0;
+    unsigned int count = 0;
     mxforeach(amap, g_append_mapping)
       if (amap->src_file_id == file_id)
         count++;
@@ -949,7 +974,7 @@ check_append_mapping() {
   }
 
   // Calculate the "longest path" -- meaning the maximum number of
-  // concatenated g_files. This is needed for displaying the progress.
+  // concatenated files. This is needed for displaying the progress.
   mxforeach(amap, g_append_mapping) {
     // Is this the first in a chain?
     mxforeach(cmp_amap, g_append_mapping) {
@@ -993,7 +1018,7 @@ check_append_mapping() {
 */
 void
 calc_max_chapter_size() {
-  // Step 1: Add all chapters from g_files that are not being appended.
+  // Step 1: Add all chapters from files that are not being appended.
   foreach(filelist_t &file, g_files) {
     if (file.appending)
       continue;
@@ -1082,6 +1107,9 @@ create_readers() {
         case FILE_TYPE_OGM:
           file.reader = new ogm_reader_c(*file.ti);
           break;
+        case FILE_TYPE_PGSSUP:
+          file.reader = new pgssup_reader_c(*file.ti);
+          break;
         case FILE_TYPE_QTMP4:
           file.reader = new qtmp4_reader_c(*file.ti);
           break;
@@ -1215,7 +1243,7 @@ add_tags_from_cue_chapters() {
 
   bool found = false;
   int tuid   = 0;
-  int i;
+  size_t i;
   for (i = 0; ptzrs_in_header_order.size() > i; ++i)
     if (ptzrs_in_header_order[i]->get_track_type() == 'v') {
       found = true;
@@ -1329,7 +1357,7 @@ create_next_output_file() {
 
   // Open the output file.
   try {
-    s_out = new mm_file_io_c(this_outfile, MODE_CREATE);
+    s_out = mm_write_cache_io_c::open(this_outfile, 20 * 1024 * 1024);
   } catch (...) {
     mxerror(boost::format(Y("The output file '%1%' could not be opened for writing (%2%).\n")) % this_outfile % strerror(errno));
   }
@@ -1401,7 +1429,7 @@ finish_file(bool last_file) {
     changed = 1;
 
   } else if (!last_file && g_no_linking) {
-    int i;
+    size_t i;
     for (i = 0; s_kax_infos->ListSize() > i; ++i)
       if (EbmlId(*(*s_kax_infos)[i]) == EBML_ID(KaxNextUID)) {
         delete (*s_kax_infos)[i];
@@ -1532,7 +1560,7 @@ finish_file(bool last_file) {
   delete s_out;
 
   // The tracks element must not be deleted.
-  int i;
+  size_t i;
   for (i = 0; i < g_kax_segment->ListSize(); ++i)
     if (NULL == dynamic_cast<KaxTracks *>((*g_kax_segment)[i]))
       delete (*g_kax_segment)[i];
@@ -1708,6 +1736,8 @@ append_track(packetizer_t &ptzr,
   if (NULL != chapters) {
     if (NULL == g_kax_chapters)
       g_kax_chapters = new KaxChapters;
+    else
+      align_chapter_edition_uids(*g_kax_chapters, *chapters);
     adjust_chapter_timecodes(*chapters, timecode_adjustment);
     move_chapters_by_edition(*g_kax_chapters, *chapters);
     delete chapters;
@@ -1758,9 +1788,9 @@ append_tracks_maybe() {
 
 /** \brief Establish deferred packetizer connections
 
-   In some cases (e.g. subtitle only g_files being appended) establishing the
+   In some cases (e.g. subtitle only files being appended) establishing the
    connections is deferred until a file containing a video track has
-   finished, too. This is necessary because the subtitle g_files themselves
+   finished, too. This is necessary because the subtitle files themselves
    are usually "shorter" than the movie they belong to. This is not the
    case if the subs are already embedded with a movie in a single file.
 
