@@ -36,6 +36,7 @@
 
 #include "common/common_pch.h"
 #include "common/fs_sys_helpers.h"
+#include "common/strings/formatting.h"
 #include "mmg/jobs.h"
 #include "mmg/mmg.h"
 #include "mmg/mmg_dialog.h"
@@ -203,7 +204,7 @@ job_run_dialog::start_next_job() {
     if ((*arg_list)[i].Length() == 0)
       opt_file->Write(wxT("#EMPTY#"));
     else {
-      std::string arg_utf8 = wxMB((*arg_list)[i]);
+      std::string arg_utf8 = escape(wxMB((*arg_list)[i]));
       opt_file->Write(arg_utf8.c_str(), arg_utf8.length());
     }
     opt_file->Write(wxT("\n"));
