@@ -18,6 +18,10 @@
 #include <wx/file.h>
 #include <wx/regex.h>
 
+#ifdef __WXMAC__
+# include <ApplicationServices/ApplicationServices.h>
+#endif
+
 #include "common/chapters/chapters.h"
 #include "common/command_line.h"
 #include "common/common_pch.h"
@@ -132,6 +136,12 @@ mmg_app::prepare_mmg_data_folder() {
 
 bool
 mmg_app::OnInit() {
+#ifdef __WXMAC__
+  ProcessSerialNumber PSN;
+  GetCurrentProcess(&PSN);
+  TransformProcessType(&PSN, kProcessTransformToForegroundApplication);
+#endif
+
   mtx_common_init();
 
   wxConfigBase *cfg;
