@@ -200,6 +200,7 @@ struct mmg_options_t {
   bool gui_debugging;
   bool set_delay_from_filename;
   bool disable_a_v_compression;
+  bool check_for_updates;
   wxString priority;
   wxArrayString popular_languages;
 
@@ -214,6 +215,7 @@ struct mmg_options_t {
     , gui_debugging(false)
     , set_delay_from_filename(false)
     , disable_a_v_compression(false)
+    , check_for_updates(true)
   {
     init_popular_languages();
   }
