@@ -15,6 +15,7 @@
 
 #include <algorithm>
 #include <wx/wx.h>
+#include <wx/aboutdlg.h>
 #include <wx/clipbrd.h>
 #include <wx/config.h>
 #include <wx/datetime.h>
@@ -23,6 +24,7 @@
 #include <wx/fileconf.h>
 #include <wx/listctrl.h>
 #include <wx/notebook.h>
+#include <wx/regex.h>
 #include <wx/statusbr.h>
 #include <wx/statline.h>
 #include <wx/strconv.h>
@@ -53,6 +55,9 @@
 #include "mmg/tabs/chapters.h"
 #include "mmg/tabs/global.h"
 #include "mmg/tabs/input.h"
+#if defined(HAVE_CURL_EASY_H)
+# include "mmg/update_checker.h"
+#endif  // defined(HAVE_CURL_EASY_H)
 #include "share/icons/32x32/mkvmergeGUI.xpm"
 
 mmg_dialog *mdlg;
@@ -69,6 +74,10 @@ mmg_dialog::mmg_dialog()
 #if defined(SYS_WINDOWS)
   , m_taskbar_msg_received(false)
 #endif
+#if defined(HAVE_CURL_EASY_H)
+  , m_checking_for_updates(false)
+  , m_update_check_dlg(NULL)
+#endif  // defined(HAVE_CURL_EASY_H)
 {
   wxBoxSizer *bs_main;
   wxPanel *panel;
@@ -169,6 +178,10 @@ mmg_dialog::mmg_dialog()
 #if defined(SYS_WINDOWS)
   RegisterWindowMessages();
 #endif
+
+#if defined(HAVE_CURL_EASY_H)
+  maybe_check_for_updates();
+#endif  // defined(HAVE_CURL_EASY_H)
 }
 
 mmg_dialog::~mmg_dialog() {
@@ -227,6 +240,10 @@ mmg_dialog::create_menus() {
   wxMenu *help_menu = new wxMenu();
   help_menu->Append(ID_M_HELP_HELP);
   help_menu->Append(ID_M_HELP_ABOUT);
+#if defined(HAVE_CURL_EASY_H)
+  help_menu->AppendSeparator();
+  help_menu->Append(ID_M_HELP_CHECK_FOR_UPDATES);
+#endif  // defined(HAVE_CURL_EASY_H)
 
   wxMenuBar *menu_bar = new wxMenuBar();
   menu_bar->Append(file_menu,    wxEmptyString);
@@ -275,6 +292,9 @@ mmg_dialog::translate_ui() {
   set_menu_item_strings(ID_M_WINDOW_CHAPTEREDITOR,     Z("&Chapter editor\tAlt-4"));
   set_menu_item_strings(ID_M_HELP_HELP,                Z("&Help\tF1"),                            Z("Show the guide to mkvmerge GUI"));
   set_menu_item_strings(ID_M_HELP_ABOUT,               Z("&About"),                               Z("Show program information"));
+#if defined(HAVE_CURL_EASY_H)
+  set_menu_item_strings(ID_M_HELP_CHECK_FOR_UPDATES,   Z("&Check for updates"),                   Z("Check online for the latest release"));
+#endif  // defined(HAVE_CURL_EASY_H)
 
   set_menu_label(this, 0, Z("&File"));
   set_menu_label(this, 1, Z("&Muxing"));
@@ -313,7 +333,7 @@ void
 mmg_dialog::on_browse_output(wxCommandEvent &evt) {
   wxFileDialog dlg(NULL, Z("Choose an output file"), last_open_dir,
                    tc_output->GetValue().AfterLast(PSEP),
-                   wxString::Format(Z("Matroska A/V files (*.mka;*.mkv)|*.mkv;*.mka|%s"), ALLFILES.c_str()),
+                   wxString::Format(Z("Matroska A/V files (*.mka;*.mkv;*.mk3d)|*.mkv;*.mka;*.mk3d|%s"), ALLFILES.c_str()),
                    wxFD_SAVE | wxFD_OVERWRITE_PROMPT);
   if(dlg.ShowModal() != wxID_OK)
     return;
@@ -626,23 +646,7 @@ mmg_dialog::display_help(int id) {
       potential_help_paths.push_back(installation_path + wxT("/doc"));
 
 #else
-    // Debian, probably others
-    potential_help_paths.push_back(wxT("/usr/share/doc/mkvtoolnix"));
-    potential_help_paths.push_back(wxT("/usr/share/doc/mkvtoolnix/doc"));
-    potential_help_paths.push_back(wxT("/usr/share/doc/mkvtoolnix-gui"));
-    // SuSE
-    potential_help_paths.push_back(wxT("/usr/share/doc/packages/mkvtoolnix"));
-    // Fedora Core
-    potential_help_paths.push_back(wxT("/usr/share/doc/mkvtoolnix-" VERSION));
-    potential_help_paths.push_back(wxT("/usr/share/doc/mkvtoolnix-gui-" VERSION));
-    // (Almost the) same for /usr/local
-    potential_help_paths.push_back(wxT("/usr/local/share/doc/mkvtoolnix"));
-    potential_help_paths.push_back(wxT("/usr/local/share/doc/packages/mkvtoolnix"));
-    potential_help_paths.push_back(wxT("/usr/local/share/doc/mkvtoolnix-" VERSION));
-    potential_help_paths.push_back(wxT("/usr/local/share/doc/mkvtoolnix-gui-" VERSION));
-    // New location
-    potential_help_paths.push_back(wxT(MTX_PKG_DATA_DIR));
-    potential_help_paths.push_back(wxT(MTX_PKG_DATA_DIR "-" VERSION));
+    potential_help_paths.push_back(wxT(MTX_DOC_DIR));
 #endif
 
     wxConfigBase *cfg = wxConfigBase::Get();
@@ -707,17 +711,16 @@ mmg_dialog::display_help(int id) {
 
 void
 mmg_dialog::on_about(wxCommandEvent &evt) {
-  wxMessageBox(wxString::Format(Z("%s\n\n"
-                                  "This GUI was written by Moritz Bunkus <moritz@bunkus.org>"
-                                  "\nBased on mmg by Florian Wagner <flo.wagner@gmx.de>\n"
-                                  "mkvmerge GUI is licensed under the GPL.\n"
-                                  "http://www.bunkus.org/videotools/mkvtoolnix/\n"
-                                  "\n"
-                                  "Help is available in form of tool tips, from the\n"
-                                  "'Help' menu or by pressing the 'F1' key."),
-                                wxUCS(get_version_info("mkvmerge GUI", true))),
-               Z("About mkvmerge's GUI"),
-               wxOK | wxCENTER | wxICON_INFORMATION);
+  wxAboutDialogInfo info;
+  info.SetName(wxU("mkvmerge GUI"));
+  info.SetVersion(wxU(get_version_info("", false)));
+  info.SetCopyright(wxU("(C) Moritz Bunkus <moritz@bunkus.org>"));
+  info.SetLicense(wxU(Z("MKVToolNix is licensed under the GNU GPL v2")) + wxU("\nhttp://www.gnu.org/licenses/old-licenses/gpl-2.0.html"));
+  info.SetWebSite(wxU("http://www.bunkus.org/videotools/mkvtoolnix/"));
+  info.SetDescription(Z("Help is available in form of tool tips, from the\n"
+                        "'Help' menu or by pressing the 'F1' key."));
+
+  wxAboutBox(info);
 }
 
 void
@@ -1323,17 +1326,20 @@ mmg_dialog::set_output_maybe(const wxString &new_output) {
 
 wxString
 mmg_dialog::suggest_file_name_extension() {
-  bool has_video = false, has_audio = false;
+  bool has_video = false, has_audio = false, has_stereo_mode = false;
 
   foreach(mmg_track_t *t, tracks) {
     if (t->is_video()) {
       has_video = true;
-      break;
+      if (t->stereo_mode >= 2)
+        has_stereo_mode = true;
+
     } else if (t->is_audio())
       has_audio = true;
   }
 
   return global_page->cb_webm_mode->IsChecked() ? wxU("webm")
+       : has_stereo_mode                        ? wxU("mk3d")
        : has_video                              ? wxU("mkv")
        : has_audio                              ? wxU("mka")
        :                                          wxU("mks");
@@ -1544,6 +1550,7 @@ mmg_dialog::save_preferences() {
   cfg->Write(wxU("gui_debugging"),                   options.gui_debugging);
   cfg->Write(wxU("set_delay_from_filename"),         options.set_delay_from_filename);
   cfg->Write(wxU("disable_a_v_compression"),         options.disable_a_v_compression);
+  cfg->Write(wxU("check_for_updates"),               options.check_for_updates);
   cfg->Write(wxU("popular_languages"),               join(wxU(" "), options.popular_languages));
 
   cfg->Flush();
@@ -1579,6 +1586,7 @@ mmg_dialog::load_preferences() {
   cfg->Read(wxU("gui_debugging"),                 &options.gui_debugging, false);
   cfg->Read(wxU("set_delay_from_filename"),       &options.set_delay_from_filename, true);
   cfg->Read(wxU("disable_a_v_compression"),       &options.disable_a_v_compression, false);
+  cfg->Read(wxU("check_for_updates"),             &options.check_for_updates, true);
   cfg->Read(wxU("popular_languages"),             &s, wxEmptyString);
 
   options.init_popular_languages(s);
@@ -1685,6 +1693,115 @@ mmg_dialog::header_editor_frame_closed(header_editor_frame_c *frame) {
   header_editor_frames.erase(find(header_editor_frames.begin(), header_editor_frames.end(), frame));
 }
 
+#if defined(HAVE_CURL_EASY_H)
+void
+mmg_dialog::maybe_check_for_updates() {
+  if (!options.check_for_updates)
+    return;
+
+  long last_check   = 0;
+  wxConfigBase *cfg = wxConfigBase::Get();
+  cfg->SetPath(wxT("/GUI/update_check"));
+  cfg->Read(wxT("last_check"), &last_check, 0);
+  if ((last_check + 24 * 60 * 60) <= wxGetLocalTime())
+    check_for_updates(false);
+}
+
+void
+mmg_dialog::on_check_for_updates(wxCommandEvent &evt) {
+  check_for_updates(true);
+}
+
+void
+mmg_dialog::on_update_check_state_changed(wxCommandEvent &evt) {
+  wxLogMessage(wxT("update state changed, now %d"), (int)evt.GetId());
+  int state = evt.GetId();
+
+  if (UPDATE_CHECK_START == state) {
+    if (m_interactive_update_check) {
+      if (NULL != m_update_check_dlg) {
+        wxLogMessage(wxT("m_update_check_dlg != NULL on start"));
+        delete m_update_check_dlg;
+      }
+
+      m_update_check_dlg = new update_check_dlg_c(this);
+      m_update_check_dlg->update_status(Z("Checking for updates online; please wait"));
+      m_update_check_dlg->Show();
+    }
+
+  } else if (UPDATE_CHECK_DONE_DIALOG_DISMISSED == state) {
+    wxMutexLocker locker(m_update_check_mutex);
+    m_checking_for_updates = false;
+
+  } else {
+    wxConfigBase *cfg = wxConfigBase::Get();
+    cfg->SetPath(wxT("/GUI/update_check"));
+
+    wxMutexLocker locker(m_update_check_mutex);
+    bool show = m_interactive_update_check;
+
+    if (!m_interactive_update_check && (UPDATE_CHECK_DONE_NEW_RELEASE == state)) {
+      bool already_shown;
+      cfg->Read(version_key_for_config(), &already_shown, false);
+      show = !already_shown;
+    }
+
+    if ((UPDATE_CHECK_DONE_NO_NEW_RELEASE == state) || (UPDATE_CHECK_DONE_NEW_RELEASE == state)) {
+      cfg->Write(wxT("last_check"), wxGetLocalTime());
+      cfg->Write(version_key_for_config(), true);
+    }
+
+    if (show) {
+      if (NULL == m_update_check_dlg) {
+        m_update_check_dlg = new update_check_dlg_c(this);
+        m_update_check_dlg->Show();
+      }
+
+      m_update_check_dlg->update_status(  UPDATE_CHECK_DONE_NO_NEW_RELEASE == state ? Z("You are already running the latest version.")
+                                        : UPDATE_CHECK_DONE_NEW_RELEASE    == state ? Z("There is a new version available online.")
+                                        :                                             Z("There was an error querying the update status."));
+      m_update_check_dlg->update_info(m_release_version);
+
+    } else
+      m_checking_for_updates = false;
+
+    m_update_check_dlg = NULL;
+
+    cfg->Flush();
+  }
+}
+
+void
+mmg_dialog::check_for_updates(bool interactive) {
+  wxMutexLocker locker(m_update_check_mutex);
+  if (m_checking_for_updates)
+    return;
+
+  m_checking_for_updates     = true;
+  m_interactive_update_check = interactive;
+
+  wxLogMessage(wxT("about to check... btw int? %d"), (int)interactive);
+
+  update_check_thread_c *checker = new update_check_thread_c(this);
+  checker->Create();
+  checker->Run();
+}
+
+void
+mmg_dialog::set_release_version(mtx_release_version_t &release_version) {
+  wxMutexLocker locker(m_update_check_mutex);
+  m_release_version = release_version;
+}
+
+wxString
+mmg_dialog::version_key_for_config() {
+  wxString version = wxU(m_release_version.latest_source.to_string());
+  wxRegEx re(wxT("[^0-9]"));
+  re.Replace(&version, wxT("_"));
+  return wxString::Format(wxT("version_%s"), version.c_str());
+}
+#endif  // defined(HAVE_CURL_EASY_H)
+
 void
 mmg_dialog::query_mkvmerge_capabilities() {
   wxString tmp;
@@ -1779,6 +1896,9 @@ BEGIN_EVENT_TABLE(mmg_dialog, wxFrame)
   EVT_MENU(ID_M_MUXING_ADD_CLI_OPTIONS,   mmg_dialog::on_add_cli_options)
   EVT_MENU(ID_M_HELP_HELP,                mmg_dialog::on_help)
   EVT_MENU(ID_M_HELP_ABOUT,               mmg_dialog::on_about)
+#if defined(HAVE_CURL_EASY_H)
+  EVT_MENU(ID_M_HELP_CHECK_FOR_UPDATES,   mmg_dialog::on_check_for_updates)
+#endif  // defined(HAVE_CURL_EASY_H)
   EVT_MENU(ID_M_FILE_LOADLAST1,           mmg_dialog::on_file_load_last)
   EVT_MENU(ID_M_FILE_LOADLAST2,           mmg_dialog::on_file_load_last)
   EVT_MENU(ID_M_FILE_LOADLAST3,           mmg_dialog::on_file_load_last)
@@ -1798,4 +1918,7 @@ BEGIN_EVENT_TABLE(mmg_dialog, wxFrame)
   EVT_MENU(ID_M_WINDOW_GLOBAL,            mmg_dialog::on_window_selected)
   EVT_MENU(ID_M_WINDOW_CHAPTEREDITOR,     mmg_dialog::on_window_selected)
   EVT_CLOSE(mmg_dialog::on_close)
+#if defined(HAVE_CURL_EASY_H)
+  EVT_COMMAND(wxID_ANY, wxEVT_MTX_UPDATE_CHECK_STATE_CHANGED, mmg_dialog::on_update_check_state_changed)
+#endif  // defined(HAVE_CURL_EASY_H)
 END_EVENT_TABLE();
