@@ -19,6 +19,13 @@
 #include <wx/html/helpctrl.h>
 #include <wx/log.h>
 
+#if defined(HAVE_CURL_EASY_H)
+# include <wx/thread.h>
+
+# include "common/version.h"
+# include "mmg/update_checker.h"
+#endif  // defined(HAVE_CURL_EASY_H)
+
 #include "mmg/mmg.h"
 
 #define ID_TC_OUTPUT                      10000
@@ -29,6 +36,8 @@
 #define ID_B_STARTMUXING                  10006
 #define ID_B_COPYTOCLIPBOARD              10007
 #define ID_B_ADD_TO_JOBQUEUE              10008
+#define ID_HLC_DOWNLOAD_URL               10009
+#define ID_B_UPDATE_CHECK_CLOSE           10010
 
 #define ID_M_FILE_NEW                     60000
 #define ID_M_FILE_LOAD                    60001
@@ -71,6 +80,7 @@
 
 #define ID_M_HELP_ABOUT                   65000
 #define ID_M_HELP_HELP                    65001
+#define ID_M_HELP_CHECK_FOR_UPDATES       65002
 
 #define HELP_ID_CONTENTS                      1
 #define HELP_ID_INTRODUCTION              10000
@@ -86,6 +96,7 @@ class tab_global;
 class tab_input;
 class job_dialog;
 class header_editor_frame_c;
+class mmg_dialog;
 
 class mmg_dialog: public wxFrame {
   DECLARE_CLASS(mmg_dialog);
@@ -131,6 +142,13 @@ public:
   bool m_taskbar_msg_received;
 #endif
 
+#if defined(HAVE_CURL_EASY_H)
+  bool m_checking_for_updates, m_interactive_update_check;
+  wxMutex m_update_check_mutex;
+  mtx_release_version_t m_release_version;
+  update_check_dlg_c *m_update_check_dlg;
+#endif  // defined(HAVE_CURL_EASY_H)
+
 public:
   mmg_dialog();
   virtual ~mmg_dialog();
@@ -219,6 +237,16 @@ public:
 
   wxString suggest_file_name_extension();
 
+#if defined(HAVE_CURL_EASY_H)
+  void maybe_check_for_updates();
+  void check_for_updates(bool interactive);
+  void set_release_version(mtx_release_version_t &release_version);
+
+  void on_check_for_updates(wxCommandEvent &evt);
+  void on_update_check_state_changed(wxCommandEvent &evt);
+  wxString version_key_for_config();
+#endif  // defined(HAVE_CURL_EASY_H)
+
 protected:
 #if defined(SYS_WINDOWS)
   virtual WXLRESULT MSWWindowProc(WXUINT msg, WXWPARAM wParam, WXLPARAM lParam);
