@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_aac.h 3950 2008-09-30 22:35:14Z mosu $
-
    class definition for the AAC output module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,12 +14,12 @@
 #ifndef __P_AAC_H
 #define __P_AAC_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "byte_buffer.h"
-#include "common.h"
-#include "pr_generic.h"
-#include "aac_common.h"
+#include "common/aac.h"
+#include "common/byte_buffer.h"
+#include "common/samples_timecode_conv.h"
+#include "merge/pr_generic.h"
 
 class aac_packetizer_c: public generic_packetizer_c {
 private:
@@ -30,6 +28,8 @@ private:
   int m_samples_per_sec, m_channels, m_id, m_profile;
   bool m_headerless, m_emphasis_present;
   byte_buffer_c m_byte_buffer;
+  samples_to_timecode_converter_c m_s2tc;
+  int64_t m_single_packet_duration;
 
 public:
   aac_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int id, int profile, int samples_per_sec, int channels,
@@ -43,7 +43,7 @@ public:
     return "AAC";
   }
 
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src, string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
 private:
   virtual unsigned char *get_aac_packet(unsigned long *header, aac_header_t *aacheader);
