@@ -14,12 +14,12 @@
 #ifndef __P_MP3_H
 #define __P_MP3_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "byte_buffer.h"
-#include "common.h"
-#include "pr_generic.h"
-#include "mp3_common.h"
+#include "common/byte_buffer.h"
+#include "common/mp3.h"
+#include "common/samples_timecode_conv.h"
+#include "merge/pr_generic.h"
 
 class mp3_packetizer_c: public generic_packetizer_c {
 private:
@@ -28,6 +28,8 @@ private:
   byte_buffer_c m_byte_buffer;
   bool m_codec_id_set, m_valid_headers_found;
   int64_t m_previous_timecode, m_num_packets_with_same_timecode;
+  samples_to_timecode_converter_c m_s2tc;
+  int64_t m_single_packet_duration;
 
 public:
   mp3_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int samples_per_sec, int channels, bool source_is_good) throw (error_c);
@@ -39,7 +41,7 @@ public:
   virtual const char *get_format_name() {
     return "MP3";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src, string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 
 private:
   virtual unsigned char *get_mp3_packet(mp3_header_t *mp3header);
