@@ -6,8 +6,6 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_pcm.h 3950 2008-09-30 22:35:14Z mosu $
-
    class definition for the PCM output module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
@@ -16,18 +14,19 @@
 #ifndef __P_PCM_H
 #define __P_PCM_H
 
-#include "os.h"
+#include "common/common_pch.h"
 
-#include "byte_buffer.h"
-#include "common.h"
-#include "pr_generic.h"
+#include "common/byte_buffer.h"
+#include "common/samples_timecode_conv.h"
+#include "merge/pr_generic.h"
 
 class pcm_packetizer_c: public generic_packetizer_c {
 private:
-  int m_packetno, m_bytes_per_second, m_samples_per_sec, m_channels, m_bits_per_sample, m_packet_size;
-  int64_t m_bytes_output;
+  int m_packetno, m_bytes_per_second, m_samples_per_sec, m_channels, m_bits_per_sample, m_samples_per_packet;
+  int64_t m_packet_size, m_samples_output;
   bool m_big_endian, m_ieee_float;
   byte_buffer_c m_buffer;
+  samples_to_timecode_converter_c m_s2tc;
 
 public:
   pcm_packetizer_c(generic_reader_c *p_reader, track_info_c &p_ti, int p_samples_per_sec, int channels, int bits_per_sample,
@@ -41,7 +40,7 @@ public:
   virtual const char *get_format_name() {
     return "PCM";
   }
-  virtual connection_result_e can_connect_to(generic_packetizer_c *src, string &error_message);
+  virtual connection_result_e can_connect_to(generic_packetizer_c *src, std::string &error_message);
 };
 
 #endif // __P_PCM_H
