@@ -6,22 +6,17 @@
    see the file COPYING for details
    or visit http://www.gnu.org/copyleft/gpl.html
 
-   $Id: p_tta.cpp 3950 2008-09-30 22:35:14Z mosu $
-
    TTA output module
 
    Written by Moritz Bunkus <moritz@bunkus.org>.
 */
 
-#include <stdlib.h>
-#include <stdio.h>
-#include <string.h>
-#include <errno.h>
+#include "common/common_pch.h"
 
-#include "common.h"
-#include "matroska.h"
-#include "p_tta.h"
-#include "tta_common.h"
+#include "common/math.h"
+#include "common/matroska.h"
+#include "common/tta.h"
+#include "output/p_tta.h"
 
 using namespace libmatroska;
 
@@ -62,7 +57,7 @@ tta_packetizer_c::process(packet_cptr packet) {
     m_samples_output += irnd(m_sample_rate * TTA_FRAME_TIME);
 
   } else {
-    mxverb(2, boost::format(Y("tta_packetizer: incomplete block with duration %1%\n")) % packet->duration);
+    mxverb(2, boost::format("tta_packetizer: incomplete block with duration %1%\n") % packet->duration);
     m_samples_output += irnd(packet->duration * m_sample_rate / 1000000000ll);
   }
 
@@ -73,7 +68,7 @@ tta_packetizer_c::process(packet_cptr packet) {
 
 connection_result_e
 tta_packetizer_c::can_connect_to(generic_packetizer_c *src,
-                                 string &error_message) {
+                                 std::string &error_message) {
   tta_packetizer_c *psrc = dynamic_cast<tta_packetizer_c *>(src);
   if (NULL == psrc)
     return CAN_CONNECT_NO_FORMAT;
