@@ -8,7 +8,7 @@ class T_253ui_language < Test
   def run
     hashes = Array.new
 
-    %w{en_US de_DE ja_JP zh_CN zh_TW}.each do |language|
+    %w{en_US de_DE ja_JP nl_NL ru_RU uk_UA zh_CN zh_TW}.each do |language|
       merge "/dev/null", "--ui-language #{language} data/avi/v.avi | sed -e 1d > #{tmp}-#{language}"
       hashes << hash_file("#{tmp}-#{language}")
 
